@@ -1,10 +1,7 @@
-package Pcore::Nginx v1.1.2;
+package Pcore::Nginx v1.1.3;
 
 use Pcore -dist, -class, -try;
 
-# TODO eval
-# use Pcore::GeoIP;
-
 has data_dir     => ( is => 'ro',   isa => Str, default => "$ENV->{DATA_DIR}" );
 has nginx_bin    => ( is => 'lazy', isa => Str, default => 'nginx' );
 has nginx_prefix => ( is => 'lazy', isa => Str, default => '/etc/nginx/' );
@@ -13,6 +10,11 @@ has conf_dir  => ( is => 'lazy', isa => Str,    init_arg => undef );
 has vhost_dir => ( is => 'lazy', isa => Str,    init_arg => undef );
 has proc      => ( is => 'ro',   isa => Object, init_arg => undef );
 
+eval {
+    require Pcore::GeoIP;
+    Pcore::GeoIP->import;
+};
+
 sub _build_conf_dir ($self) {
     my $conf_dir = $self->data_dir . 'nginx/';
 
@@ -34,8 +36,8 @@ sub run ($self) {
         pid                => $self->conf_dir . 'nginx.pid',
         mime_types         => $ENV->share->get('/data/nginx/mime.types'),
         error_log          => $self->data_dir . 'nginx-error.log',
-        geoip_country_path => $ENV->share->get('/data/geoip_country.dat'),
-        geoip_city_path    => $ENV->share->get('/data/geoip_city.dat'),
+        geoip_country_path => $ENV->share->get('/data/geoip_country.dat') // undef,
+        geoip_city_path    => $ENV->share->get('/data/geoip_city.dat') // undef,
         vhost_dir          => $self->vhost_dir,
         ssl_dhparam        => $ENV->share->get('/data/nginx/dhparam-4096.pem'),
     };
@@ -62,7 +64,21 @@ sub add_vhost ( $self, $name, $cfg ) {
     return;
 }
 
+sub is_vhost_exists ( $self, $name ) {
+    return -f $self->vhost_dir . "$name.nginx";
+}
+
 1;
+## -----SOURCE FILTER LOG BEGIN-----
+##
+## PerlCritic profile "pcore-script" policy violations:
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
+## | Sev. | Lines                | Policy                                                                                                         |
+## |======+======================+================================================================================================================|
+## |    3 | 13                   | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
+##
+## -----SOURCE FILTER LOG END-----
 __END__
 =pod
 
